package X6FRs_4.KQgRr5e_0.YghfZG_14;

import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
/* compiled from: ActionMode.java */
/* loaded from: classes.dex */
public abstract class QxJ9d_1 {
    public Object KQgRr5e_0;
    public boolean QxJ9d_1;

    /* compiled from: ActionMode.java */
    /* loaded from: classes.dex */
    public interface KQgRr5e_0 {
        void KQgRr5e_0(QxJ9d_1 qxJ9d_1);

        boolean KQgRr5e_0(QxJ9d_1 qxJ9d_1, Menu menu);

        boolean KQgRr5e_0(QxJ9d_1 qxJ9d_1, MenuItem menuItem);

        boolean QxJ9d_1(QxJ9d_1 qxJ9d_1, Menu menu);
    }

    public abstract Menu KQgRr5e_0();

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public abstract MenuInflater m465KQgRr5e_0();

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public abstract View m466KQgRr5e_0();

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public abstract CharSequence m467KQgRr5e_0();

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public abstract void m469KQgRr5e_0();

    public abstract void KQgRr5e_0(int i);

    public abstract void KQgRr5e_0(View view);

    public abstract void KQgRr5e_0(CharSequence charSequence);

    public void KQgRr5e_0(Object obj) {
        this.KQgRr5e_0 = obj;
    }

    public abstract CharSequence QxJ9d_1();

    /* renamed from: QxJ9d_1  reason: collision with other method in class */
    public abstract void m471QxJ9d_1();

    public abstract void QxJ9d_1(int i);

    public abstract void QxJ9d_1(CharSequence charSequence);

    /* renamed from: QxJ9d_1  reason: collision with other method in class */
    public abstract boolean m472QxJ9d_1();

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public Object m468KQgRr5e_0() {
        return this.KQgRr5e_0;
    }

    public void KQgRr5e_0(boolean z) {
        this.QxJ9d_1 = z;
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public boolean m470KQgRr5e_0() {
        return this.QxJ9d_1;
    }
}
